==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/lv-LV/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Konts ar šo e-pasta adresi jau pastāv.',
    'account_not_found'      => 'Lietotājvārds vai parole nav pareiza.',
    'account_not_activated'  => 'Šis lietotāja konts nav aktivizēts.',
    'account_suspended'      => 'Šī lietotāja konta darbība ir apturēta.',
    'account_banned'         => 'Šis lietotāja konts ir aizliegts.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Jūs esat veiksmīgi pieteicies',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
    ),

    'signin' => array(
        'error'   => 'Mēģinot pieslēgties, radās problēma. Lūdzu, mēģiniet vēlreiz.',
        'success' => 'Jūs esat veiksmīgi pieteicies',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Mēģinot izveidot kontu, radās problēma. Lūdzu, mēģiniet vēlreiz.',
        'success' => 'Konts veiksmīgi izveidots.',
    ),

    'forgot-password' => array(
        'error'   => 'Mēģinot atkopt paroles kodu, radās problēma. Lūdzu, mēģiniet vēlreiz.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Mēģinot atiestatīt paroli, radās problēma. Lūdzu, mēģiniet vēlreiz.',
        'success' => 'Jūsu parole ir veiksmīgi atiestatīta.',
    ),


);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/lv-LV/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Konts ar šo e-pasta adresi jau pastāv.',
    'account_not_found'      => 'Lietotājvārds vai parole nav pareiza.',
    'account_not_activated'  => 'Šis lietotāja konts nav aktivizēts.',
    'account_suspended'      => 'Šī lietotāja konta darbība ir apturēta.',
    'account_banned'         => 'Šis lietotāja konts ir aizliegts.',
    'throttle'               => 'Too many failed login attempts. Please try again in :minutes minutes.',

    'two_factor' => array(
        'already_enrolled'      => 'Your device is already enrolled.',
        'success'               => 'Jūs esat veiksmīgi pieteicies',
        'code_required'         => 'Two-factor code is required.',
        'invalid_code'          => 'Two-factor code is invalid.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Mēģinot pieslēgties, radās problēma. Lūdzu, mēģiniet vēlreiz.',
        'success' => 'Jūs esat veiksmīgi pieteicies',
    ),

    'logout' => array(
        'error'   => 'There was a problem while trying to log you out, please try again.',
        'success' => 'You have successfully logged out.',
    ),

    'signup' => array(
        'error'   => 'Mēģinot izveidot kontu, radās problēma. Lūdzu, mēģiniet vēlreiz.',
        'success' => 'Konts veiksmīgi izveidots.',
    ),

    'forgot-password' => array(
        'error'   => 'Mēģinot atkopt paroles kodu, radās problēma. Lūdzu, mēģiniet vēlreiz.',
        'success' => 'If that email address exists in our system, a password recovery email has been sent.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Mēģinot atiestatīt paroli, radās problēma. Lūdzu, mēģiniet vēlreiz.',
        'success' => 'Jūsu parole ir veiksmīgi atiestatīta.',
    ),


);
